import { IonButton, IonIcon } from '@ionic/react';
import { cloudDownload } from 'ionicons/icons';
import React, { Fragment, useRef } from 'react';
import { useDB } from 'react-pouchdb';
import { getGpxAsXmlString } from '../../db/gpx';

const GpxExport: React.FC<{ gpx: any }> = (props: { gpx: any }) => {
  const db = useDB();

  const hiddenLinkElement = useRef<HTMLAnchorElement>(null);

  var downloadName;

  if (props.gpx.metadata.name !== undefined) {
    downloadName = props.gpx.metadata.name;
  } else if (props.gpx.gpx.metadata.name !== undefined) {
    downloadName = `${props.gpx.gpx.metadata.name}.gpx`;
  } else {
    downloadName = `track-${props.gpx.metadata.lastModified}.gpx`;
  }

  const download = async (event: any) => {
    event.preventDefault();
    console.log('download()');
    const gpxAsXml = await getGpxAsXmlString(db, props.gpx._id);
    console.log(`gpxAsXml: ${gpxAsXml}`);
    const blob = new Blob([gpxAsXml], {
      type: 'application/gpx+xml',
    });
    const fileDownloadUrl = URL.createObjectURL(blob);
    console.log(`fileDownloadUrl: ${fileDownloadUrl}`);
    console.log(`hiddenLinkElement.current: ${hiddenLinkElement.current}`);
    hiddenLinkElement.current!.href = fileDownloadUrl;
    hiddenLinkElement.current?.click();
    URL.revokeObjectURL(fileDownloadUrl);
    hiddenLinkElement.current!.href = '';
  };

  return (
    <Fragment>
      <IonButton id='gpx-export-button' onClick={download}>
        <IonIcon icon={cloudDownload} title='Export' slot='icon-only' />
      </IonButton>
      <a className='hidden' download={downloadName} ref={hiddenLinkElement}>
        download
      </a>
    </Fragment>
  );
};

export default GpxExport;
